@@ -33,7 +33,9 @@ case "$1" in
         chmod u=rw,g=r,o= $SERVER_CONFIG
 
         set +e
-        if [ -f "$VAR_DIR/$USER_DB" ];then
+        echo ""|sqlite /var/lib/benno-web/bennoweb.sqlite 2>/dev/null
+        dbretval=$?
+        if [ -f "$VAR_DIR/$USER_DB" ] && [ $dbretval = 0 ];then
             # convert database from slite2 to sqlite3
             mv "$VAR_DIR/$USER_DB" "$VAR_DIR/${USER_DB}2"
             echo .dump| sqlite "$VAR_DIR/${USER_DB}2" | sqlite3 "$VAR_DIR/$USER_DB"
