@@ -369,7 +369,7 @@ class Application extends ApplicationConfig
         $this->TPL->assign('DEBUG',$this->DEBUG);
 
         if (isset($this->config['DBTYPE'])) {
-            $this->DB =& new DBAccess($this->config['DBTYPE'],$this->config['DBUSER'],
+            $this->DB = new DBAccess($this->config['DBTYPE'],$this->config['DBUSER'],
                                      $this->config['DBPASS'],$this->config['DBHOST'],
                                      $this->config['DATABASE']);
         }
@@ -696,8 +696,7 @@ class Application extends ApplicationConfig
      * parameter => value pairs that will be set for the new uri.
      *
      * @access public
-     * @param string $action
-     * @param array $params and values array
+     * @param string | array $params and values array
      */
     function redirect ($action,$plist=array())
     {
@@ -705,8 +704,13 @@ class Application extends ApplicationConfig
         $this->setSession('LAST_ACTION',$CURRENT_ACTION);
 
         $params = session_name().'='.session_id().'&CA='.$action;
-        foreach ($plist as $var => $value) {
-            $params .= '&'.$var.'='.$value;
+        if (is_array($plist)) {
+            foreach ($plist as $var => $value) {
+                $params .= '&'.$var.'='.$value;
+            }
+        }
+        else {
+            $params .= '&'. $plist;
         }
         if ($this->DEBUG) {
             $this->log("[SPAF2/Application]:REDIRECT ===> $action");
@@ -801,6 +805,45 @@ class Application extends ApplicationConfig
     }
 
 
+    /**
+     * getMsg
+     *
+     * Get the $MSG string of the message symbol.
+     *
+     * Fetches the message from the file $confdir/ERRORMSG
+     *
+     * @access public
+     * @param string $msg_sym symbol
+     * @return string $message
+     */
+    function getMsg ($msg_sym='')
+    {
+        $msg_string = '';
+        if (! $fd = @fopen ($this->message_file, "r")) {
+	        $this->log('ERROR: Cannot read message file '.$this->message_file);
+        }
+        else {
+            while (!feof ($fd)) {
+                $buffer = fgets($fd, 1024);
+                if (preg_match("/^#/",$buffer)) continue;
+                if (preg_match("/^\s*$/",$buffer)) continue;
+                list($param,$value) = preg_split ("/\s*=\s*/",$buffer,2);
+                if ($param == 'ERR_DEFAULT') {
+                    $msg_default = rtrim($value);
+                    continue;
+                }
+                if ($param == $msg_sym) {
+                    $msg_string = rtrim($value);
+                    break;
+                }
+            }
+            fclose($fd);
+            if ($msg_string == '') $msg_string = $msg_default;
+        }
+        return $msg_string;
+    }
+
+ 
     /**
      * setMsg
      *
@@ -814,23 +857,7 @@ class Application extends ApplicationConfig
      */
     function setMsg ($msg_sym='')
     {
-        $msg_string = '';
-        if (! $fd = @fopen ($this->message_file, "r")) {
-	        $this->log('ERROR: Cannot read message file '.$this->message_file);
-        }
-        else {
-            while (!feof ($fd)) {
-                $buffer = fgets($fd, 255);
-                if (preg_match("/^#/",$buffer)) continue;
-                if (preg_match("/^\s*$/",$buffer)) continue;
-                list($param,$value) = preg_split ("/\s*=\s*/",$buffer,2);
-                if ($param == $msg_sym) {
-                    $msg_string = rtrim($value);
-                    break;
-                }
-            }
-            fclose($fd);
-        }
+        $msg_string = $this->getMsg($msg_sym);
         $this->assign('MSG',$msg_string);
         return TRUE;
     }
