@@ -39,13 +39,15 @@ $mailTo = $App->getParam('mailTo');
 
 try {
     $rawMail = $Backend->fetchRaw($sessionMailId);
-    $uniqid = uniqid();
-    $rawMail = preg_replace('/^Message-Id:\s<?(.+?)>?$/im',"Message-Id: <$uniqid.$1>\nX-Benno-Original-Message-Id: $1\nX-Benno-Info: Diese Mail wurde als Kopie einer archivierten Mail aus Benno MailArchiv zugestellt.",$rawMail);
+    $rawMail = preg_replace('/^Message-Id:/im','X-Benno-Resent-Message-Id:',$rawMail);
+
+    $msgIdHeader = 'Message-ID: <'.uniqid('',true).'@'.php_uname('n').'>';
+
     $send_to = escapeshellarg($mailTo);
     $sendmail = "$sendmail_cmd -i -r $mail_from $send_to 2>&1";
     $ph = popen($sendmail,'w');
     if (!$ph) { throw new Exception("Cannot exec command \"$sendmail\""); }
-    $ret = fwrite($ph,$rawMail);
+    $ret = fwrite($ph,$msgIdHeader."\r\n".$rawMail);
     if (!$ret) {
         fclose($ph);
         throw new Exception("Cannot write mail to \"$sendmail\"");
