@@ -79,10 +79,6 @@ class Backend
         $body   = $maildata['body'];
         $header = $maildata['header'];
 
-        if (!$body) {
-            throw new Exception('NO_EMAIL');
-        }
-
         $EMail = new EMail($sessionMailId,$bennoId,$header['From'],$header['To'],$header['Cc'],$header['Bcc'],$header['Subject'],$header['Date'],$header['Size'],$body);
 
         foreach ($maildata['attachments'] as $atm) {
@@ -269,7 +265,7 @@ class Backend
         $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE); 
         if ($httpCode != 200) {
             $App->log('[Backend/query] HTTP error: '.$httpCode);
-            throw new Exception('ERR_REQUEST');
+            throw new Exception('ERR_HTTP_'.$httpCode);
         }
 
         // split header / body
