@@ -132,6 +132,12 @@ class Query
         if ($App->DEBUG >= 1) {
             $App->log('[Query] '.$query_string);
         }
+        // replace special chars
+        $search = array('&');
+        $replace = array('%26');
+        // Achtung! Hier liegt ein Lucene Query-String vor!
+        $query_string = str_replace($search,$replace,$query_string);
+
         return $query_string;
     }
 
