@@ -174,6 +174,9 @@ class UserDA extends Persistence
 
             $errvalue = stream_get_contents($pipes[2]);
             fclose($pipes[2]);
+            if ($errvalue) {
+                error_log('Authentication script error: '.$errvalue);
+            }
 
             $return_value = proc_close($process);
         }
