@@ -31,4 +31,7 @@
  * Suite 330, Boston, MA  02111-1307  USA
  */
 
+// set language version for template (datepicker localization)
+$App->assign('LANG',$App->lang);
+
 ?>
